==> snipe-it-7.0.11.zip: snipe-it-7.0.11/resources/lang/ru-RU/admin/hardware/form.php <==
<?php

return [
    'bulk_delete'		=> 'Подвердите массовое удаление активов',
    'bulk_restore'      => 'Подвердите массовое восстановление активов', 
  'bulk_delete_help'	=> 'Просмотрите активны, выбранные для удаления. После удаления активы могут быть восстановлены, но уже не будет привязаны к пользователям, к которым они привязаны сейчас.',
  'bulk_restore_help'	=> 'Проверьте активы для массового восстановления. После восстановления эти активы не будут связаны с пользователями, с которыми они были ранее связаны.',
  'bulk_delete_warn'	=> 'Вы собираетесь удалить :asset_count активов.',
  'bulk_restore_warn'	=> 'Вы собираетесь восстановить :asset_count активов.',
    'bulk_update'		=> 'Редактировать выбранное',
    'bulk_update_help'	=> 'Эта форма позволяет Вам обновить несколько объектов за раз. Заполняйте только те поля, которые нужно изменить. Пустые поля останутся без изменений. ',
    'bulk_update_warn'	=> 'Вы собираетесь отредактировать свойства одного ресурса.|Вы собираетесь отредактировать свойства :asset_count assets.',
    'bulk_update_with_custom_field' => 'Обратите внимание: активы содержат :asset_model_count различных типов моделей.',
    'bulk_update_model_prefix' => 'На моделях', 
    'bulk_update_custom_field_unique' => 'Это уникальное поле и не может быть отредактированы через массовую обработку.',
    'checkedout_to'		=> 'Привязан к',
    'checkout_date'		=> 'Дата выдачи',
    'checkin_date'		=> 'Дата возврата',
    'checkout_to'		=> 'Привязать к',
    'cost'				=> 'Цена',
    'create'			=> 'Создать актив',
    'date'				=> 'Дата покупки',
    'depreciation'	    => 'обесценивание',
    'depreciates_on'	=> 'Обесценивается на',
    'default_location'	=> 'Текущее расположение',
    'default_location_phone' => 'Телефон местоположения по умолчанию',
    'eol_date'			=> 'Срок эксплуатации',
    'eol_rate'			=> 'EOL величина',
    'expected_checkin'  => 'Ожидаемая дата возврата',
    'expires'			=> 'Истекает',
    'fully_depreciated'	=> 'Полностью изношен',
    'help_checkout'		=> 'Если вы хотите привязать этот актив немедленно, выберите статус "Готов к установке" из списка ниже. ',
    'mac_address'		=> 'MAC Адрес',
    'manufacturer'		=> 'Производитель',
    'model'				=> 'Модель',
    'months'			=> 'Месяцев',
    'name'				=> 'Имя актива',
    'notes'				=> 'Примечания',
    'order'				=> 'Номер заказа',
    'qr'				=> 'QR-код',
    'requestable'		=> 'Пользователи могут запросить этот актив',
    'redirect_to_all'   => 'Return to all :type',
    'redirect_to_type'   => 'Go to :type',
    'redirect_to_checked_out_to'   => 'Go to Checked Out to',
    'select_statustype'	=> 'Выберите тип статуса',
    'serial'			=> 'Серийный номер',
    'status'			=> 'Статус',
    'tag'				=> 'Тег актива',
    'update'			=> 'Изменить актив',
    'warranty'			=> 'Гарантия',
        'warranty_expires'		=> 'Срок действия гарантии',
    'years'				=> 'Лет',
    'asset_location' => 'Обновить местоположение актива',
    'asset_location_update_default_current' => 'Обновить местоположение по умолчанию и фактическое местоположение',
    'asset_location_update_default' => 'Обновить только местоположение по умолчанию',
    'asset_location_update_actual' => 'Обновить только фактическое местоположение',
    'asset_not_deployable' => 'Этот статус актива не подлежит развертыванию. Этот актив не может быть проверен.',
    'asset_deployable' => 'Этот статус доступен для развертывания. Этот актив может быть привязан.',
    'processing_spinner' => 'Обработка... (Это может занять некоторое время на больших файлах)',
    'optional_infos'  => 'Дополнительная информация',
    'order_details'   => 'Информация, связанная с заказом'
];

==> snipe-it-7.0.13.zip: snipe-it-7.0.13/resources/lang/ru-RU/admin/hardware/form.php <==
<?php

return [
    'bulk_delete'		=> 'Подвердите массовое удаление активов',
    'bulk_restore'      => 'Подвердите массовое восстановление активов', 
  'bulk_delete_help'	=> 'Просмотрите активны, выбранные для удаления. После удаления активы могут быть восстановлены, но уже не будет привязаны к пользователям, к которым они привязаны сейчас.',
  'bulk_restore_help'	=> 'Проверьте активы для массового восстановления. После восстановления эти активы не будут связаны с пользователями, с которыми они были ранее связаны.',
  'bulk_delete_warn'	=> 'Вы собираетесь удалить :asset_count активов.',
  'bulk_restore_warn'	=> 'Вы собираетесь восстановить :asset_count активов.',
    'bulk_update'		=> 'Редактировать выбранное',
    'bulk_update_help'	=> 'Эта форма позволяет Вам обновить несколько объектов за раз. Заполняйте только те поля, которые нужно изменить. Пустые поля останутся без изменений. ',
    'bulk_update_warn'	=> 'Вы собираетесь отредактировать свойства одного ресурса.|Вы собираетесь отредактировать свойства :asset_count assets.',
    'bulk_update_with_custom_field' => 'Обратите внимание: активы содержат :asset_model_count различных типов моделей.',
    'bulk_update_model_prefix' => 'На моделях', 
    'bulk_update_custom_field_unique' => 'Это уникальное поле и не может быть отредактированы через массовую обработку.',
    'checkedout_to'		=> 'Привязан к',
    'checkout_date'		=> 'Дата выдачи',
    'checkin_date'		=> 'Дата возврата',
    'checkout_to'		=> 'Привязать к',
    'cost'				=> 'Цена',
    'create'			=> 'Создать актив',
    'date'				=> 'Дата покупки',
    'depreciation'	    => 'обесценивание',
    'depreciates_on'	=> 'Обесценивается на',
    'default_location'	=> 'Текущее расположение',
    'default_location_phone' => 'Телефон местоположения по умолчанию',
    'eol_date'			=> 'Срок эксплуатации',
    'eol_rate'			=> 'EOL величина',
    'expected_checkin'  => 'Ожидаемая дата возврата',
    'expires'			=> 'Истекает',
    'fully_depreciated'	=> 'Полностью изношен',
    'help_checkout'		=> 'Если вы хотите привязать этот актив немедленно, выберите статус "Готов к установке" из списка ниже. ',
    'mac_address'		=> 'MAC Адрес',
    'manufacturer'		=> 'Производитель',
    'model'				=> 'Модель',
    'months'			=> 'Месяцев',
    'name'				=> 'Имя актива',
    'notes'				=> 'Примечания',
    'order'				=> 'Номер заказа',
    'qr'				=> 'QR-код',
    'requestable'		=> 'Пользователи могут запросить этот актив',
    'redirect_to_all'   => 'Вернуться ко всем :type',
    'redirect_to_type'   => 'Перейти к :type',
    'redirect_to_checked_out_to'   => 'Перейти к заметке',
    'select_statustype'	=> 'Выберите тип статуса',
    'serial'			=> 'Серийный номер',
    'status'			=> 'Статус',
    'tag'				=> 'Тег актива',
    'update'			=> 'Изменить актив',
    'warranty'			=> 'Гарантия',
        'warranty_expires'		=> 'Срок действия гарантии',
    'years'				=> 'Лет',
    'asset_location' => 'Обновить местоположение актива',
    'asset_location_update_default_current' => 'Обновить местоположение по умолчанию и фактическое местоположение',
    'asset_location_update_default' => 'Обновить только местоположение по умолчанию',
    'asset_location_update_actual' => 'Обновить только фактическое местоположение',
    'asset_not_deployable' => 'Этот статус актива не подлежит развертыванию. Этот актив не может быть проверен.',
    'asset_not_deployable_checkin' => 'That asset status is not deployable. Using this status label will checkin the asset.',
    'asset_deployable' => 'Этот статус доступен для развертывания. Этот актив может быть привязан.',
    'processing_spinner' => 'Обработка... (Это может занять некоторое время на больших файлах)',
    'optional_infos'  => 'Дополнительная информация',
    'order_details'   => 'Информация, связанная с заказом'
];
